==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterPredicateBuilder.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterPredicateBuilder extends ClusterPredicateFluentImpl<ClusterPredicateBuilder> implements VisitableBuilder<ClusterPredicate,ClusterPredicateBuilder>{
  public ClusterPredicateBuilder() {
    this(false);
  }
  public ClusterPredicateBuilder(Boolean validationEnabled) {
    this(new ClusterPredicate(), validationEnabled);
  }
  public ClusterPredicateBuilder(ClusterPredicateFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterPredicateBuilder(ClusterPredicateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterPredicate(), validationEnabled);
  }
  public ClusterPredicateBuilder(ClusterPredicateFluent<?> fluent,ClusterPredicate instance) {
    this(fluent, instance, false);
  }
  public ClusterPredicateBuilder(ClusterPredicateFluent<?> fluent,ClusterPredicate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withRequiredClusterSelector(instance.getRequiredClusterSelector());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterPredicateBuilder(ClusterPredicate instance) {
    this(instance,false);
  }
  public ClusterPredicateBuilder(ClusterPredicate instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withRequiredClusterSelector(instance.getRequiredClusterSelector());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterPredicateFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterPredicate build() {
    ClusterPredicate buildable = new ClusterPredicate(fluent.getRequiredClusterSelector());
    return buildable;
  }
  
}

==> open-cluster-management-cluster-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterPredicateBuilder.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterPredicateBuilder extends ClusterPredicateFluent<ClusterPredicateBuilder> implements VisitableBuilder<ClusterPredicate,ClusterPredicateBuilder>{
  public ClusterPredicateBuilder() {
    this(false);
  }
  public ClusterPredicateBuilder(Boolean validationEnabled) {
    this(new ClusterPredicate(), validationEnabled);
  }
  public ClusterPredicateBuilder(ClusterPredicateFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterPredicateBuilder(ClusterPredicateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterPredicate(), validationEnabled);
  }
  public ClusterPredicateBuilder(ClusterPredicateFluent<?> fluent,ClusterPredicate instance) {
    this(fluent, instance, false);
  }
  public ClusterPredicateBuilder(ClusterPredicateFluent<?> fluent,ClusterPredicate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterPredicate());

    if (instance != null) {
      fluent.withRequiredClusterSelector(instance.getRequiredClusterSelector());
      fluent.withRequiredClusterSelector(instance.getRequiredClusterSelector());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterPredicateBuilder(ClusterPredicate instance) {
    this(instance,false);
  }
  public ClusterPredicateBuilder(ClusterPredicate instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterPredicate());

    if (instance != null) {
      this.withRequiredClusterSelector(instance.getRequiredClusterSelector());
      this.withRequiredClusterSelector(instance.getRequiredClusterSelector());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterPredicateFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterPredicate build() {
    ClusterPredicate buildable = new ClusterPredicate(fluent.buildRequiredClusterSelector());
    return buildable;
  }
  
}
